"use strict";
/**
 * @license
 * Copyright 2020 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.unsortedSegmentSumConfig = void 0;
var tfjs_1 = require("@tensorflow/tfjs");
var nodejs_kernel_backend_1 = require("../nodejs_kernel_backend");
exports.unsortedSegmentSumConfig = {
    kernelName: tfjs_1.UnsortedSegmentSum,
    backendName: 'tensorflow',
    kernelFunc: function (args) {
        var _a = args.inputs, x = _a.x, segmentIds = _a.segmentIds;
        var backend = args.backend;
        var numSegments = args.attrs.numSegments;
        var opAttrs = [
            (0, nodejs_kernel_backend_1.createTensorsTypeOpAttr)('T', x.dtype),
            (0, nodejs_kernel_backend_1.createTensorsTypeOpAttr)('Tindices', 'int32'),
            (0, nodejs_kernel_backend_1.createTensorsTypeOpAttr)('Tnumsegments', 'int32')
        ];
        var numSegmentsT = (0, tfjs_1.scalar)(numSegments, 'int32');
        var res = backend.executeSingleOutput(tfjs_1.UnsortedSegmentSum, opAttrs, [x, segmentIds, numSegmentsT]);
        numSegmentsT.dispose();
        return res;
    }
};
